@@ -5,7 +5,7 @@ use warnings;
 use v5.10;
 
 # ABSTRACT: Template Renderer Plugin for Mojolicious
-our $VERSION = '1.49'; # VERSION
+our $VERSION = '1.50'; # VERSION
 
 use base 'Mojolicious::Plugin';
 
@@ -36,7 +36,7 @@ Mojolicious::Plugin::TtRenderer - Template Renderer Plugin for Mojolicious
 
 =head1 VERSION
 
-version 1.49
+version 1.50
 
 =head1 SYNOPSIS
 
@@ -57,6 +57,10 @@ L<Mojolicious::Plugin::TtRenderer::Engine> directly.
 
 =encoding utf-8
 
+=for stopwords Bjørn
+Szász
+Árpád
+
 =head1 OPTIONS
 
 These are the options that can be passed in as arguments to this plugin.
@@ -121,7 +125,7 @@ C<utf-87>
 
 C<128>
 
-=item RELATIZE
+=item RELATIVE
 
 C<1> (true)
 
@@ -263,6 +267,8 @@ spleenjack
 
 Árpád Szász
 
+Сергей Романов
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Ask Bjørn Hansen.
